﻿using System;
using Abp.Dependency;
using Abp.Domain.Entities;
using Abp.Localization;
using Abp.Web.Models;

namespace Personball.Demo.Web
{
    public class CustomExceptionErrorInfoConverter
        : IExceptionToErrorInfoConverter, ITransientDependency
    {
        private readonly ILocalizationManager _localizationManager;

        public IExceptionToErrorInfoConverter Next { set; private get; }

        public CustomExceptionErrorInfoConverter(ILocalizationManager localizationManager)
        {
            _localizationManager = localizationManager;
        }

        public ErrorInfo Convert(Exception exception)
        {
            while (exception is AggregateException && exception.InnerException != null)
            {
                exception = exception.InnerException;
            }

            if (exception is DemoBusinessException)
            {
                var ex = exception as DemoBusinessException;
                return new ErrorInfo(ex.Code, L(ex.Message));
            }

            if (exception is EntityNotFoundException)
            {
                return new ErrorInfo((int)ErrorCode.ItemNotExists, L(ErrorCode.ItemNotExists.ToString()));
            }

            if (exception is ArgumentException)
            {
                var argEx = exception as ArgumentException;
                var argMsg = exception.Message ?? L(ErrorCode.RequestParametersError.ToString());
                return new ErrorInfo((int)ErrorCode.RequestParametersError, argMsg, $"ParamName:{argEx.ParamName}");
            }

            return Next.Convert(exception);
        }

        private string L(string name)
        {
            try
            {
                return _localizationManager.GetString(DemoConsts.LocalizationSourceName, name);
            }
            catch (Exception)
            {
                return name;
            }
        }
    }
}